package com.zehong.system.mapper;

import java.util.List;
import com.zehong.system.domain.TTechnologyProcess;

/**
 * 工业流程图Mapper接口
 * 
 * @author zehong
 * @date 2026-07-15
 */
public interface TTechnologyProcessMapper 
{
    /**
     * 查询工业流程图
     * 
     * @param processId 工业流程图ID
     * @return 工业流程图
     */
    public TTechnologyProcess selectTTechnologyProcessById(Long processId);

    /**
     * 查询工业流程图列表
     * 
     * @param tTechnologyProcess 工业流程图
     * @return 工业流程图集合
     */
    public List<TTechnologyProcess> selectTTechnologyProcessList(TTechnologyProcess tTechnologyProcess);

    /**
     * 新增工业流程图
     * 
     * @param tTechnologyProcess 工业流程图
     * @return 结果
     */
    public int insertTTechnologyProcess(TTechnologyProcess tTechnologyProcess);

    /**
     * 修改工业流程图
     * 
     * @param tTechnologyProcess 工业流程图
     * @return 结果
     */
    public int updateTTechnologyProcess(TTechnologyProcess tTechnologyProcess);

    /**
     * 删除工业流程图
     * 
     * @param processId 工业流程图ID
     * @return 结果
     */
    public int deleteTTechnologyProcessById(Long processId);

    /**
     * 批量删除工业流程图
     * 
     * @param processIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTTechnologyProcessByIds(Long[] processIds);
}
